@@ -2,11 +2,48 @@ from acceldata_sdk.torch_client import TorchClient
 import acceldata_sdk.constants as const
 from acceldata_sdk.models.tags import AssetLabel
 from acceldata_sdk.models.profile import ProfilingType
+from acceldata_sdk.models.assetType import AssetType
 from acceldata_sdk.models.profile import AutoProfileConfiguration, Profile, ProfileRequest, ProfilingType
 import pprint
 
 pp = pprint.PrettyPrinter(indent=4)
 
+# torch_credentials = {
+#     'url':  'https://acceldata.dev.10.90.3.89.nip.io',
+#     'access_key':  '21DK0CVJUAE0LET',
+#     'secret_key':  '1PT5E06TLCHKGELZCOEC7LLOCPYHJO'
+# }
+# torchClient = TorchClient(**torch_credentials)
+# ds_id = torchClient.get_datasource('1', True)
+# status = ds_id.get_crawler_status()
+# # asset = torchClient.get_asset(4)
+# # sample_data_asset = asset.sample_data()
+#
+# asset = torchClient.get_asset(4)
+# start_profile_asset = asset.start_profile(ProfilingType.FULL)
+# profile_status = start_profile_asset.get_status()
+# if profile_status['profileRequest']['status'] == 'IN PROGRESS':
+#     cancel_res = start_profile_asset.cancel()
+#     assert cancel_res is not None
+# exit()
+# from acceldata_sdk.torch_client import TorchClient
+#
+# torchClient = TorchClient(url="https://winterfel.qetest.acceldata.dev", access_key="S58A3VBB7L3T5PZ",
+#                           secret_key="51YPWKNLXOUZMI4QTTKIPRKYQBZX9W",do_version_check=False)
+#
+# torchClient = TorchClient(url="https://torchtenant.unified.acceldata.tech", access_key="TXU3N9MDGN7ZIZD",
+#                                   secret_key="OGWX9ONR37CQFKL2EL7S4NBKPY433G", do_version_check=False)
+# torch_credentials = {
+#     'url': 'https://torch.acceldata.local:5443/torch',
+#     'access_key': 'P04IM8FNQRUCRTU',
+#     'secret_key': 'E6LL9YUPMG4BDTJHT2VZD75HW0B8E5',
+#     'do_version_check': 'True'
+# }
+# torchClient = TorchClient(**torch_credentials)
+# assemblyName = "COMPUTE_WH"
+# torchClient.get_datasource(assemblyName,False)
+# torchClient.get_datasource(const.AssetSourceType.SNOWFLAKE)
+# exit()
 # base_path = 's3a://demo-data-plane-one/execution_result'
 # good_data_location = 's3a://demo-data-plane-one/execution_result/2022-09-29/segmented_cc/_1664445283208/successrecords'
 # stage_path_suffix=good_data_location.lstrip(base_path)
@@ -38,18 +75,34 @@ pp = pprint.PrettyPrinter(indent=4)
 #     'access_key': 'V05DG18TV4MAF93',
 #     'secret_key': 'VZF8O9Q5G6GUE08MQY5A8CA0TAE5KD'
 # }
+# torch_credentials = {
+#     'url': 'https://torch.acceldata.local:5443/torch',
+#     'access_key': 'P04IM8FNQRUCRTU',
+#     'secret_key': 'E6LL9YUPMG4BDTJHT2VZD75HW0B8E5',
+#     'do_version_check': 'True'
+# }
+
 torch_credentials = {
-    'url': 'https://torch.acceldata.local:5443/torch',
-    'access_key': 'P04IM8FNQRUCRTU',
-    'secret_key': 'E6LL9YUPMG4BDTJHT2VZD75HW0B8E5',
-    'do_version_check': 'True'
+    'url':  'https://acceldata.dev.10.90.3.89.nip.io',
+    'access_key': '21DK0CVJUAE0LET',
+    'secret_key': '1PT5E06TLCHKGELZCOEC7LLOCPYHJO'
 }
+
 # torch_credentials = {
 #     'url': 'https://yubi.torch.acceldata.dev/torch',
 #     'access_key': 'SAQ8XAOLSSLAD16',
 #     'secret_key': 'KL5C4UA5XBQ2HBUMQPATJ3FB45HRH9'
 # }
 
+
+recon_rule_id=1
+# import pdb;pdb.set_trace()
+torch_client = TorchClient(**torch_credentials)
+
+recon_rule2 = torch_client.execute_policy(const.PolicyType.DATA_QUALITY, recon_rule_id, sync=True, incremental=False, pipeline_run_id=401)
+sync_execution_result = recon_rule2.get_result()
+exit(0)
+
 ######## suman 2.3.0 test
 # torch_credentials = {
 #     'url': 'https://torchtenant.unified.acceldata.tech',
