@@ -17,4 +17,9 @@ torch_credentials = {
     'url': os.getenv('TORCH_CATALOG_URL', 'https://acceldata.dev.10.90.3.89.nip.io'),
     'access_key': os.getenv('TORCH_ACCESS_KEY', '21DK0CVJUAE0LET'),
     'secret_key': os.getenv('TORCH_SECRET_KEY', '1PT5E06TLCHKGELZCOEC7LLOCPYHJO')
-}
\ No newline at end of file
+}
+
+ds_name = 'sf_ds'
+ds_id = '1'
+asset_uid = 'sf_ds.FINANCE.FINANCE.ACCELDATA_CUSTOMERS_IND'
+asset_id = 4
\ No newline at end of file
